<?php
require_once(dirname(__FILE__) . '/../component-helper.inc.php');
block_non_admins();

route_request();
function route_request() {

    $update = grab_request_var('update');
    if (!empty($update))
        update_deployed();

    show_deployed();
}

function show_deployed() {

    global $db;

    $title = _('Your Deployed Dashboards');
    child_page($title, 'home');

    echo well_top_page_header($title);

    $bind = array(
        ':user_id' => intval($_SESSION['user_id']),
        );
    $deployed = $db->exec_query(
        'SELECT 
        d2.dashboard_name AS deployed_from,
        d1.dashboard_id AS dashboard_id, 
        d1.dashboard_name AS dashboard_name, 
        d1.sync AS sync, 
        d1.user_id AS user_id 
        FROM 
        dashboards d1 
        LEFT JOIN
        dashboards d2 
        ON 
        d2.dashboard_id = d1.sync
        WHERE d1.sync IN (SELECT dashboard_id FROM dashboards WHERE user_id = :user_id)', $bind);

    if (!is_array($deployed) || count($deployed) == 0) {

        echo '<p>' . _("You haven't deployed any syncronized dashboards yet!") . '<br /><a href="deploydashboards.php">' . _('Click here to deploy a few!') . 
        '</a></p>';
        exit();
    }

    echo '<p>' . _("Use this utility to unsyncronize or remove any dashboards that you've deployed. When you syncronize a dashboard to a non-administrator, they have no way of removing it or editing it.") . '</p><br /><a href="deploydashboards.php">' . _('Click here to to go back to Deploy Dashboards') . '</a><br /><br />';

    ?>


    <style>
    table.deploy thead tr th.deploy-th,
    table.deploy tbody tr td {
        vertical-align: top !important;
        text-align: center !important;
    }
    table.deploy thead tr th.deploy-th input, 
    table.deploy tbody tr td input {
        float: none;
    }
    </style>

    <script type="text/javascript">
        $(function() {
            $('#remove_all').click(function() {
                $(".remove").prop("checked", $(this).prop("checked")); 
            });
            $('#unsync_all').click(function() {
                $(".unsync").prop("checked", $(this).prop("checked")); 
            });
        });
    </script>

    <form>

    <h5 class="ul"><?php echo _('Syncronized Dashboards'); ?></h5>
    <p><?php echo _("Use this table to specify which dashboards to unsync or remove."); ?></p>

    <table class="table table-condensed table-striped table-bordered table-auto-width deploy">
        <thead>
            <tr>
                <th class="deploy-th"><?php echo _('Remove'); ?>
                    <div><input type="checkbox" id="remove_all" value="1"></div>
                </th>
                <th class="deploy-th"><?php echo _('Unsync'); ?>
                    <div><input type="checkbox" id="unsync_all" value="1"></div>
                </th>
                <th class="deploy-th"><?php echo _('Deployed From'); ?></th>
                <th class="deploy-th"><?php echo _('Dashboard Name'); ?></th>
                <th class="deploy-th"><?php echo _('User'); ?></th>
            </tr>
        </thead>
        <tbody>
            <?php
            foreach ($deployed as $d) {

                $user = get_username($d['user_id']);
                echo '
                    <tr>
                        <td><input type="checkbox" class="remove" name="remove[' . $d['dashboard_id'] . ']" value="1" /></td>
                        <td><input type="checkbox" class="unsync" name="unsync[' . $d['dashboard_id'] . ']" value="1" /></td>
                        <td>' . $d['deployed_from'] . '</td>
                        <td>' . $d['dashboard_name'] . '</td>
                        <td>' . $user . '</td>
                    </tr>';
            }
            ?>
        </tbody>
    </table>

    <div id="formButtons">
        <input type="submit" class="btn btn-sm btn-primary" name="update" id="updateButton" value="<?php echo _('Un-Deploy Dashboards'); ?>" />
        <input type="submit" class="btn btn-sm btn-default" name="cancel" id="cancelButton" value="<?php echo _('Cancel'); ?>" />
    </div>

    </form>
<?php
}

function update_deployed() {

    global $db;

    $bind = array(
        ':user_id' => intval($_SESSION['user_id']),
        );
    $deployed = $db->exec_query(
        'SELECT dashboard_id, dashboard_name, sync, user_id FROM dashboards WHERE sync IN (SELECT dashboard_id FROM dashboards WHERE user_id = :user_id)', $bind);

    if (!is_array($deployed)) {
        flash_message(_("You have no deployed dashboards to remove or unsync."), 'error');
        return;
    }

    $remove = grab_request_var('remove');
    $unsync = grab_request_var('unsync');

    $removed_count = null;
    $unsynced_count = null;
    $errmsg = '';

    if (is_array($remove)) {
        $removed_count = 0;
        foreach ($remove as $id => $r) {

            // check if this id belongs to us...
            $belongs = false;
            foreach ($deployed as $d) {
                if ($d['dashboard_id'] == $id) {
                    $belongs = true;
                    break;
                }
            }

            if ($belongs) {

                $bind = array(':dashboard_id' => $id);
                $removed = $db->exec_query('DELETE FROM dashboards WHERE dashboard_id = :dashboard_id', $bind);
                if ($removed)
                    $removed_count++;
                else
                    $errmsg .= _('Unable to delete dashboard_id: ') . $id . '<br />';
            }
        }
    }

    if (is_array($unsync)) {
        $unsynced_count = 0;
        foreach ($unsync as $id => $u) {

            // check if this id belongs to us...
            $belongs = false;
            foreach ($deployed as $d) {
                if ($d['dashboard_id'] == $id) {
                    $belongs = true;
                    break;
                }
            }

            if ($belongs) {

                $bind = array(':dashboard_id' => $id);
                $unsynced = $db->exec_query('UPDATE dashboards SET sync = 0 WHERE dashboard_id = :dashboard_id', $bind);
                if ($unsynced)
                    $unsynced_count++;
                else
                    $errmsg .= _('Unable to unsync dashboard_id: ') . $id . '<br />';
            }
        }
    }

    if (!empty($errmsg)) {

        $errmsg .= sprintf(_('But successfully unsynced %s dashboards and removed %s dashboards!'), $unsynced_count, $removed_count);
        flash_message($errmsg, 'error');
    } else {

        flash_message(sprintf(_('Successfully unscyned %s dashboards and removed %s dashboards!'), $unsynced_count, $removed_count));
    }

}