<?php
require_once(dirname(__FILE__) . '/../includes/base.inc.php');

block_non_admins();

route_request();
function route_request() {

    $pageopt = get_pageopt();

    // if we chose a multi button, we just redirect the page opt based on the value
    $multi = grab_request_var('multi');
    $valid_multi_values = array('delete', 'enable', 'disable');
    if (in_array($multi, $valid_multi_values))
        $pageopt = $multi;

    switch ($pageopt) {

        case 'update':
            update_server();
            break;

        case 'delete':
            unfuse_server();
            break;

        case 'enable':
        	enable_server();
        	break;

        case 'disable':
        	disable_server();
        	break;

        case 'edit':
            edit_server();
            break;

        default:
            show_servers();
            break;
    }
}

function show_servers($reload = false) {

    if ($reload)
        reload_page('/admin/', 'servers.php');
    
    $title = _('Manage Fused Servers');
    child_page($title);

    echo well_top_page_header($title);
    ?>

    <div class="page-buttons">
        <a href="?edit" class="btn btn-sm btn-primary">
            <i class="fa fa-server"></i>
            <span><?php echo _('Fuse a Server'); ?></span>
        </a>
    </div>

    <?php
    $select_statement = "SELECT * FROM servers";
    $opts = array(
        'display_footer' => false,
        'table_class' => 'table table-condensed table-hover table-bordered table-striped',
        'pre_table_html' => 
            '<script>
                $(function() { 
                    $("#select_all").click(function() { 
                        $("input.servers_checkbox").prop("checked", $(this).prop("checked")); 
                    }); 
                    $("input.servers_checkbox").closest("tr").click(function(ev) {                        
                        // cancel if click is on an input or on a th
                        if (ev.target.nodeName === "INPUT" || ev.target.nodeName === "TH" || ev.target.nodeName === "IMG" || ev.target.nodeName == "SPAN")
                            return;

                        $(this).find("input.servers_checkbox").click();
                    });
                    $("a.action_button.delete.server").click(function() {
                        return confirm("' . _('Are you sure you want to delete this server?') . '");
                    });
                    $("button.delete").click(function() {
                        return confirm("' . _('Are you sure you want to delete these servers?') . '");
                    });
                });
            </script>',

        'columns' => array(
            'checkbox' => array(
                'th' => '<input type="checkbox" id="select_all" class="servers_checkbox" />',
                'td' => '<input type="checkbox" name="server_id[]" value="%server_id%" class="servers_checkbox" />',
                'replace_macros' => true,
                'width' => '16px',
                ),
            'name' => array(
            	'th' => _('Server Name'),
            	'sortable' => true,
            	'width' => '20%',
                'eval' =>
                    "return show_is_disabled('%name%', %enabled%, 'Server is disabled');"
            	),

            'server_type' => array(
                'th' =>  _('Server Type'),
                'sortable' => true,
                'eval' =>
                	"return server_type_to_readable(%server_type%);",
                'width' => '15%',
                ),
            'authentication_type' => array(
                'th' =>  _('Authentication Type'),
                'sortable' => true,
                'eval' =>
                	"switch(%authentication_type%) {
                        case AUTH_TYPE_FUSEKEY: return _('Fusekey Authentication');
                        case AUTH_TYPE_SESSION: return _('Session Authentication');
                        case AUTH_TYPE_BASIC:   return _('Basic Authentication');
                	}",
                'width' => '15%',
                ), 
            'location' => array(
                'th' => _('Location'),
                'sortable' => true,
                'width' => '15%',
                ),
            'url' => array(
            	'th' => _('URL'),
            	'sortable' => true,
            	),
            'actions' => array(
                'th' => _('Actions'),
                'transform' => 'servers_build_action_td',
                'replace_macros' => true,
                'width' => '10%'
                ),
            ),
        'with_selected' => array(
            array(
                'value' => 'delete',
                'class' => 'delete',
                'title' => _('Delete'),
                'img' => get_icon_url('cross.png'),
                ),
            array(
                'value' => 'enable',
                'title' => _('Enable'),
                'img' => get_icon_url('server_go.png'),
                ),
            array(
                'value' => 'disable',
                'title' => _('Disable'),
                'img' => get_icon_url('server_disable.png'),
                ),
            ),
        );
    echo '<form method="post">';
    echo get_paged_table($select_statement, null, $opts);
    echo '</form>';
}

function edit_server() {

    // server_id of -1 means add, otherwise edit
    $server_id = grab_request_var('server_id', -1);
    if (is_array($server_id))
    	$server_id = -1;

    // just to help with readability
    $add_server = $server_id == -1 ? true : false;

    $enabled = intval(get_server_attr('enabled', $server_id, 1));
    if ($add_server)
        $enabled = 1;

    $name = get_server_attr('name', $server_id, '');
    $name = grab_request_var('name', $name);

    $server_type = get_server_attr('server_type', $server_id, SERVER_TYPE_XI);
    $server_type = intval(grab_request_var('server_type', $server_type));
        
    $url = get_server_attr('url', $server_id, '');
    $url = grab_request_var('url', $url);

    $cgi_bin = get_server_attr('cgi_bin', $server_id, '');
    $cgi_bin = grab_request_var('cgi_bin', $cgi_bin);
    
    $fusekey = get_server_attr('fusekey', $server_id, '');
    $fusekey = grab_request_var('fusekey', $fusekey);
    
    $username = get_server_attr('username', $server_id, '');
    $username = grab_request_var('username', $username);
    
    $password = get_server_attr('password', $server_id, '');
    if (!empty($password))
        $password = 'password_set';

    $global_auth_interval = get_option('auth_interval', DEFAULT_AUTH_INTERVAL);
    $auth_interval = get_server_attr('auth_interval', $server_id, $global_auth_interval);
    if (empty($auth_interval))
        $auth_interval = $global_auth_interval;
    $auth_interval = grab_request_var('auth_interval', $auth_interval, $auth_interval);
    $auth_interval = intval($auth_interval);

    $global_polling_interval = get_option('polling_interval', DEFAULT_POLLING_INTERVAL);
    $polling_interval = get_server_attr('polling_interval', $server_id, $global_polling_interval);
    if (empty($polling_interval))
        $polling_interval = $global_polling_interval;
    $polling_interval = grab_request_var('polling_interval', $polling_interval, $polling_interval);
    $polling_interval = intval($polling_interval);

    $ignore_xi_meta = get_server_attr('ignore_xi_meta', $server_id, 0);
    
    $location = get_server_attr('location', $server_id, '');
    $location = grab_request_var('location', $location);
    
    $timezone = get_server_attr('timezone', $server_id, '');
    $timezone = grab_request_var('timezone', $timezone);
    
    $notes = get_server_attr('notes', $server_id, '');
    $notes = grab_request_var('notes', $notes);

    get_timezones_and_selected($timezones, $timezone);

    $fusekey_initial_style = '';
    $cgi_bin_initial_style = ' style="display: none;" ';
    if ($server_type == SERVER_TYPE_CORE) {

        $fusekey_initial_style = ' style="display: none;" ';
        $cgi_bin_initial_style = '';
    }

    // set some of the displays based on whether we're adding or editing
    $page_header = $add_server ? _('Fuse a Server') : _('Edit Fused Server');
    $submit_button_value = $add_server ? _('Fuse Server') : _('Update Fused Server');

    child_page($page_header);
    echo well_top_page_header($page_header);

    ?>
    <script type="text/javascript">
    $(function() {

        // click the test fusion settings button
        $('#test_fusion_settings').click(function() {

            // the img urls            
            var img_success = "<?php echo get_icon_url('ok_small.png') ?>";
            var img_failure = "<?php echo get_icon_url('critical_small.png') ?>";

            // remove any previous messages after the test fusion settings button
            $('span.test_result').css('visibility', 'hidden');

            var $main_test_result = $('span.test_result.main');

            var password = $('#password').val();

            var opts = array2json({
                "server_id":            $('#server_id').val(),
                "url":                  $('#url').val().trim(),
                "server_type":          $('#server_type').val(),
                "cgi_bin":              $('#cgi_bin').val(),
                "fusekey":              $('#fusekey').val(),
                "username":             $('#username').val().trim(),
                "password":             password
            });
            
            post_ajax_data_with_callback('test_server', opts, 
                function(data) { 
                    var general_error = false;
                    if (data) {

                        // data comes in like this:
                        // "fusekey:{$fusekey_auth};username:{$username_auth};"
                        var auth = data.split(';');
                        var fusekey = auth[0].split(':');
                        var username = auth[1].split(':');

                        if (fusekey.length == 2 && username.length == 2) {

                            fusekey = fusekey[1];
                            username = username[1];

                            var $fusekey_test_result = $('span.test_result.fusekey');
                            var $username_test_result = $('span.test_result.username');
                            
                            if (fusekey == <?php echo AUTH_TYPE_FUSEKEY; ?>) {

                                $fusekey_test_result.find('img').attr('src', img_success);
                                $fusekey_test_result.css('visibility', 'visible');

                            } else {
                                if (fusekey != 'empty') {

                                    $fusekey_test_result.find('img').attr('src', img_failure);
                                    $fusekey_test_result.css('visibility', 'visible');
                                }
                            }

                            if (username == <?php echo AUTH_TYPE_SESSION; ?> || username == <?php echo AUTH_TYPE_BASIC; ?>) {
                                
                                $username_test_result.find('img').attr('src', img_success);
                                $username_test_result.css('visibility', 'visible');

                            } else {
                                if (username != 'empty') {
                                    
                                    $username_test_result.find('img').attr('src', img_failure);
                                    $username_test_result.css('visibility', 'visible');
                                }
                            }
                        } else {
                            general_error = true;
                        }
                    } else {
                        general_error = true;
                    }

                    if (general_error) {

                        $main_test_result.find('img').attr('src', img_failure);
                        $main_test_result.find('span').html("<?php echo _('Something went wrong'); ?>");
                        $main_test_result.css('visibility', 'visible');
                    }
                }
            );
        });

        // hide/show some fields depending on server_type selected value
        $('#server_type').change(function() {

            var $server_type_val = $(this).val();

            if ($server_type_val == <?php echo SERVER_TYPE_CORE; ?>) {

                $('#cgi_bin_row').show();
                $('#fusekey_row').hide();
                $('#ignore_xi_meta_row').hide();

            } else {

                $('#cgi_bin_row').hide();
                $('#fusekey_row').show();
                $('#ignore_xi_meta_row').show();
            }

        }).change();
    });
    </script>
    <form method="post"  action="?update"  class="formbuilder" >
        <input name="update"  value="1"  type="hidden"  />
        <input name="server_id" id="server_id" value="<?php echo $server_id; ?>"  type="hidden"  />
        <div class="formbuilder-div formbuilder" style="min-height: 365px;"  >
            <h5 class="ul" >
                <?php echo _('General Settings'); ?>
            </h5>
            <table class="formbuilder-table formbuilder" >
                <tr>
                    <td class="vt">
                        <label for="name" >
                            <?php echo _('Server Name'); ?>:
                        </label>
                    </td>
                    <td>
                        <input name="name"  placeholder="<?php echo _('Server Name'); ?>"  value="<?php echo encode_html($name); ?>"  type="text"  id="name"  class="form-control textfield" required="true"  />
                        <div class="subtext">
                            <?php echo _('This is a name you use to distinguish this server in Fusion.'); ?>
                        </div>
                    </td>
                </tr>
                <tr>
                    <td>
                        <label for="server_type" >
                            <?php echo _('Server Type'); ?>:
                        </label>
                    </td>
                    <td>
                        <select name="server_type"  id="server_type"  class="dropdown form-control" >
                            <?php echo get_options_from_array(servers_get_server_type_options(), $server_type); ?>
                        </select>
                    </td>
                </tr>
                <tr>
                    <td class="vt">
                        <label for="url" >
                            <?php echo _('URL'); ?>:
                        </label>
                    </td>
                    <td>
                        <input name="url"  placeholder="<?php echo _('URL'); ?>"  id="url"  value="<?php echo encode_html($url); ?>"  type="text"  class="form-control textfield" required="true"   />
                        <div class="subtext">
                            <?php echo _('The URL that Fusion and Fusion users can access this server at.'); ?>
                        </div>
                    </td>
                </tr>
                <tr id="cgi_bin_row" <?php echo $cgi_bin_initial_style; ?>>
                    <td>
                        <label for="cgi_bin" >
                            <?php echo _('CGI Path'); ?>:
                        </label>
                    </td>
                    <td>
                        <input name="cgi_bin"  placeholder="/cgi-bin/"  id="cgi_bin"  value="<?php echo encode_html($cgi_bin); ?>" type="text"  class="form-control textfield"  />
                    </td>
                </tr>
                <tr>
                    <td>
                    </td>
                    <td class="checkbox">
                        <label class="checkbox">
                            <input name="enabled"  value="1"  type="checkbox"  <?php is_checked($enabled); ?>  id="enabled"  class="checkbox"  />
                            <?php echo _('Enable this server'); ?>
                        </label>
                    </td>
                </tr>
            </table>
        </div>
        <div class="formbuilder-div formbuilder" style="min-height: 365px;" >
            <h5 class="ul" >
                <?php echo _('Fusion Settings'); ?>
            </h5>
            <table class="formbuilder-table formbuilder" >
                <tr id="fusekey_row" <?php echo $fusekey_initial_style; ?> class="vt">
                    <td>
                        <label for="fusekey" >
                            <?php echo _('Fusekey'); ?>:
                        </label>
                    </td>
                    <td>
                        <input name="fusekey"  placeholder="Fusekey"  id="fusekey"  value="<?php echo encode_html($fusekey); ?>"  type="text"  class="form-control textfield"  />
                        <span class="test_result fusekey" style="visibility: hidden;">
                            <img src="<?php echo get_icon_url('ok_small.png') ?>">
                        </span>
                        <div class="subtext">
                            <?php echo _('The Fusekey is available in XI 5.4.0+'); ?>
                            <?php e_pop(
                                _('Fusekey'),
                                _("You can find your Fusekey in Nagios XI by navigating to the 'Admin' section, selecting 'System Settings' and then selecting the 'Integration' tab. The Fusekey only works with Nagios XI 5.4.0 or newer.")); ?>
                        </div>
                    </td>
                </tr>
                <tr>
                    <td>
                        <label for="username"  class="vt">
                            <?php echo _('Username'); ?>:
                        </label>
                    </td>
                    <td>
                        <input name="username"  placeholder="Username"  id="username"  value="<?php echo encode_html($username); ?>"  type="text"  class="form-control textfield"  required="true"  />
                        <span class="test_result username" style="visibility: hidden;">
                            <img src="<?php echo get_icon_url('ok_small.png') ?>">
                        </span>
                        <div class="subtext">
                            <?php echo _("The Administrator account for this Nagios server."); ?>
                        </div>
                    </td>
                </tr>
                <tr>
                    <td>
                        <label for="password" >
                            <?php echo _('Password'); ?>:
                        </label>
                    </td>
                    <td>
                        <input name="password"  id="password"  type="password"  class="form-control textfield" value="<?php echo encode_html($password); ?>"  required="true"  />
                    </td>
                </tr>
                <tr>
                    <td></td>
                    <td>
                        <button name="test_fusion_settings"  id="test_fusion_settings"  class="btn btn-sm btn-info"  type="button">
                            <?php echo _('Test Fusion Settings'); ?>
                        </button>
                        <br />
                        <span class="test_result main" style="visibility: hidden;">
                            <img src="<?php echo get_icon_url('ok_small.png') ?>">&nbsp;<span>&nbsp;</span>
                        </span>
                    </td>
                </tr>
            </table>
        </div>
        <div class="formbuilder-div formbuilder clear">
            <h5 class="ul" >
                <?php echo _('Polling Settings'); ?>
            </h5>
            <table class="formbuilder-table formbuilder" >
                <tr>
                    <td class="vt">
                        <label for="auth_interval" >
                            <?php echo _('Authentication Interval'); ?>:
                        </label>
                    </td>
                    <td>
                        <input name="auth_interval"  value="<?php echo $auth_interval; ?>"  size="5"  type="text"  id="auth_interval"  class="form-control textfield"  />
                        <?php echo _('Seconds'); ?>
                        <div class="subtext">
                            <?php echo _('Define the frequency at which this server is checked for authentication.'); ?>
                            <?php e_pop(
                                _('Authentication Interval'), 
                                _('Authentication is a single check against the server to ensure both connectivity (information used for polling) and that the specified credentials are still correct. You want to keep this value relatively low.')); ?>
                        </div>
                    </td>
                </tr>
                <tr>
                    <td class="vt">
                        <label for="polling_interval" >
                            <?php echo _('Polling Interval'); ?>:
                        </label>
                    </td>
                    <td>
                        <input name="polling_interval"  value="<?php echo $polling_interval; ?>"  size="5"  type="text"  id="polling_interval"  class="form-control textfield"  />
                        <?php echo _('Seconds'); ?>
                        <div class="subtext">
                            <?php echo _('Define the frequency at which this server is polled for data.'); ?>
                            <?php e_pop(
                                _('Polling Interval'), 
                                _("Larger Nagios XI and Core systems will benefit from a larger number here, due to the fact that it takes longer to poll and process the data for these large systems.")); ?>
                        </div>
                    </td>
                </tr>
                <tr id="ignore_xi_meta_row">
                    <td>
                    </td>
                    <td class="checkbox">
                        <label class="checkbox">
                            <input value="1"  name="ignore_xi_meta"  type="checkbox"  id="ignore_xi_meta" <?php is_checked($ignore_xi_meta); ?> class="checkbox"  />
                            <?php echo _('Ignore XI host/service meta data'); ?>
                            <?php e_pop(
                                _('Ignore XI host/service meta data'), 
                                _("This only applies to XI servers that you're fusing to. Meta data refers to the following data: ") .
                                '<ul>
                                    <li>Hosts and Services that are disabled</li>
                                    <li>Host and Service acknowledgement information</li>
                                    <li>Hosts and Services that are flapping</li>
                                    <li>Hosts and Services that are in downtime</li>
                                </ul>' .
                                _("For a large system, this can allow you to set a much lower value for the polling_interval, as poll speed is reduced by up to 70%. This is not recommended for an XI system with less than 20,000 Host and Service checks.")
                                ); ?>
                            <div class="subtext" style="color: red;">
                                <em><?php echo _('Enabling this option is not recommended unless you have an extremely large system.'); ?></em>
                            </div>
                        </label>
                    </td>
                </tr>
            </table>
        </div>
        <div class="formbuilder-div formbuilder" >
            <h5 class="ul" >
                <?php echo _('Additional Information'); ?>:
            </h5>
            <table class="formbuilder-table formbuilder" >
                <tr>
                    <td>
                        <label for="location" >
                            <?php echo _('Server Location'); ?>:
                        </label>
                    </td>
                    <td>
                        <input name="location"  placeholder="<?php echo _('Server Location'); ?>"  type="text" value="<?php echo encode_html($location); ?>" id="location"  class="form-control textfield"  />
                        <div class="subtext">
                            <?php echo _("User-defined data for keeping track of your server's location."); ?>
                        </div>
                    </td>
                </tr>
                <tr>
                    <td>
                        <label for="timezone" >
                            <?php echo _('Timezone'); ?>:
                        </label>
                    </td>
                    <td>
                        <select name="timezone"  id="timezone"  class="dropdown form-control" >
                            <?php echo get_options_from_array($timezones, $timezone); ?>
                        </select>
                        <div class="subtext">
                            <?php echo _("The timezone that this server resides in."); ?>
                            <?php e_pop(
                                _('Timezone'),
                                _("Defining a timezone for your server allows Fusion to convert any time-related data from your fused server for storage and viewing.")); ?>
                        </div>
                    </td>
                </tr>
                <tr>
                    <td class="vt" >
                        <label for="notes" >
                            <?php echo _('Server Notes'); ?>:
                        </label>
                    </td>
                    <td>
                        <textarea name="notes"  placeholder="<?php echo _('Server Notes'); ?>"  style="width: 340px; height: 120px;"  id="notes"  class="form-control" ><?php echo encode_html($notes); ?></textarea>
                    </td>
                </tr>
            </table>
        </div>
        <div class="clear"></div>
        <div class="formbuilder-buttons">
            <input name="submit"  value="<?php echo $submit_button_value; ?>"  class="btn btn-primary btn-sm"  type="submit"  />
            <input name="cancel"  value="<?php echo _('Cancel'); ?>"  class="btn btn-default btn-sm cancel-validator"  type="submit"  />
        </div>
    </form>
    <?php
}

function unfuse_server() {

    check_nagios_session_protector();

    $server_id = grab_request_var('server_id', -1);

    $count = 0;

    if (is_array($server_id)) {
    	foreach($server_id as $this_server_id) {
    		if (delete_server($this_server_id))
    			$count++;
    	}
    } else {
    	if ($server_id > 0) {
    		if (delete_server($server_id))
    			$count++;
    	}
    }

    flash_message(sprintf(_('%d servers successfully deleted.'), $count));
    show_servers(true);
    exit();
}

function enable_server() {

	$count = servers_set_server_attr('enabled', 1);
    flash_message(sprintf(_('%d servers enabled successfully.'), $count));
    show_servers(true);
    exit();
}

function disable_server() {

	$count = servers_set_server_attr('enabled', 0);
    flash_message(sprintf(_('%d servers disabled successfully.'), $count));
    show_servers(true);
    exit();
}

function update_server() {

    check_nagios_session_protector();

    // if we aren't updating or we pressed cancel then just go ahead and show_servers
    $update = grab_request_var('update', false);
    $cancel = grab_request_var('cancel', false);
    if (!$update || $cancel)
        flash_message_cb_and_exit('show_servers');

    $server_id = intval(grab_request_var('server_id', -1));

    $enabled = intval(grab_request_var('enabled', 0));
    $name = grab_request_var('name', '');
    $server_type = intval(grab_request_var('server_type', SERVER_TYPE_XI));

    $url = grab_request_var('url', '');
    $cgi_bin = grab_request_var('cgi_bin', '');
    $fusekey = grab_request_var('fusekey', '');
    $username = grab_request_var('username', '');
    $password = grab_request_var('password', '');

    $auth_interval = grab_request_var('auth_interval', 0);
    $polling_interval = grab_request_var('polling_interval', 0);
    $ignore_xi_meta = intval(grab_request_var('ignore_xi_meta', 0));

    $location = grab_request_var('location', '');
    $timezone = grab_request_var('timezone', '');
    $notes = grab_request_var('notes', '');

    $server_password = get_server_attr('password', $server_id, '');
    $auth_types = servers_get_authentication_type_options();

    set_option('configured_fused_server', 1);

    $errmsg = '';
    if (empty($name)) 
        $errmsg .= _('Name cannot be blank.') . '<br>';

    if ($server_id == -1 && get_server($name))
        $errmsg .= _('A server with this name already exists.') . '<br>';

    if (empty($url))
        $errmsg .= _('URL is required.') . '<br>';

    $testurl = strtolower($url);
    if (strpos($testurl, 'http://') !== 0 && strpos($testurl, 'https://') !== 0)
        $errmsg .= _('Please enter a valid URL.') . '<br>';

    if (empty($username))
        $errmsg .= _('Username is a required field!') . '<br>';

    if (empty($password))
        $errmsg .= _('Password is a required field!') . '<br>';

    if (!empty($errmsg))
        flash_message_cb_and_exit('edit_server', $errmsg, 'error');

    // we determine the appropriate auth type for the user
    $authentication_type = -1; 
    if ($server_type == SERVER_TYPE_CORE) {
        $authentication_type = AUTH_TYPE_BASIC;
    } else if ($server_type == SERVER_TYPE_XI) {
        if (!empty($fusekey)) {
            $authentication_type = AUTH_TYPE_FUSEKEY;
        } else {
            $authentication_type = AUTH_TYPE_SESSION;
        }
    } /* else if ...nna ..nls.. */

    // adding or updating?
    if ($server_id == -1) {

        // adding

    	$server_id = 
        add_server($enabled, $name, $server_type, $authentication_type, $url, $cgi_bin, $location, $timezone, $notes);

    	if ($server_id === false) {

    		flash_message(_('Something went wrong adding server.'), 'error');

        } else {

            // Add the fuse host to the server
            if ($authentication_type == AUTH_TYPE_FUSEKEY)
                add_fuse_host_to_xi($server_id, $fusekey);

    		flash_message(_('Server added successfully!'));
        }

    } else {

        // updating

        if (!is_valid_timezone($timezone))
            $timezone = date_default_timezone_get();

        set_server_attr('name', $name, $server_id);
    	set_server_attr('enabled', $enabled, $server_id);
    	set_server_attr('server_type', $server_type, $server_id);
    	set_server_attr('authentication_type', $authentication_type, $server_id);
    	set_server_attr('url', $url, $server_id);
        set_server_attr('cgi_bin', $cgi_bin, $server_id);
    	set_server_attr('location', $location, $server_id);
        set_server_attr('timezone', $timezone, $server_id);
    	set_server_attr('notes', $notes, $server_id);
    }

    // server id will either be false or a valid number by this point
    if ($server_id !== false) {

        set_server_attr('ignore_xi_meta', $ignore_xi_meta, $server_id);

        // update fusekey
        if (!empty($fusekey))
            set_server_attr('fusekey', $fusekey, $server_id);

        // update username
        if (!empty($username))
            set_server_attr('username', $username, $server_id);

        // if we already have a good server_password..
        if (!empty($server_password)) {

            if ($password != 'password_set')
                set_server_attr('password', _encrypt($password), $server_id);
        }

        // we did not have a good server_password (means we are adding)
        else {
            set_server_attr('password', _encrypt($password), $server_id);
        }

        // only update the auth interval if its different than the global
        $global_auth_interval = get_option('auth_interval', DEFAULT_AUTH_INTERVAL);
        if ($auth_interval != $global_auth_interval && !empty($auth_interval))
            set_server_attr('auth_interval', $auth_interval, $server_id);

        // only update the polling interval if its different than the global
        $global_polling_interval = get_option('polling_interval', DEFAULT_POLLING_INTERVAL);
        if ($polling_interval != $global_polling_interval && !empty($polling_interval))
            set_server_attr('polling_interval', $polling_interval, $server_id);
    }

    // only refresh the top for server drop down and the subsys status
    // if the name changed
    show_servers($reload = true);
}

function servers_get_server_type_options() {

    return array(
        SERVER_TYPE_XI      => _('Nagios XI'),
        SERVER_TYPE_CORE    => _('Nagios Core'),
        // SERVER_TYPE_NNA  => _('Nagios Network Analyzer'),
        // SERVER_TYPE_NLS  => _('Nagos Log Server'),
        );
}

function servers_get_authentication_type_options() {

    return array(
        AUTH_TYPE_FUSEKEY   => _('Fusekey Authentication'),
        AUTH_TYPE_SESSION   => _('Session Authentication'),
        AUTH_TYPE_BASIC     => _('Basic Authentication'),
        );
}


function servers_set_server_attr($attr, $value) {

    check_nagios_session_protector();

    $server_id = grab_request_var('server_id');

    $count = 0;

    if (empty($server_id))
    	return $count;

    if (is_array($server_id)) {
    	foreach ($server_id as $this_server_id) {
    		if (set_server_attr($attr, $value, $this_server_id))
    			$count++;
    	}
    } else {
    	if (set_server_attr($attr, $value, $server_id))
    		$count++;
    }

    return $count;
}
