<?php
require_once(dirname(__FILE__) . '/../includes/base.inc.php');

block_non_admins();

route_request();
function route_request() {

    $pageopt = get_pageopt();

    // if we chose a multi button, we just redirect the page opt based on the value
    $multi = grab_request_var('multi');
    $valid_multi_values = array('delete', 'unlock', 'enable', 'disable', 'email');
    if (in_array($multi, $valid_multi_values)) {
        $pageopt = $multi;
    }

    switch ($pageopt) {

        case 'update':
            update_user();
            break;

        case 'delete':
            delete_users();
            break;

        case 'edit':
            edit_user();
            break;

        case 'unlock':
            unlock_users();
            break;

        case 'enable':
            enable_users();
            break;

        case 'disable':
            disable_users();
            break;

        case 'masquerade':
            masquerade_as_user();
            break;

        case 'email':
            email_users();
            break;

        default:
            show_users();
            break;
    }
}


// get the user id submitted and masquerade + redirect
function masquerade_as_user() {

    check_nagios_session_protector();

    $user_id = users_get_request_user_id($return_int_only = true);

    if (!is_valid_user_id($user_id))
        flash_message_cb_and_exit('show_users', _('Invalid specified user ID.'), 'error');

    masquerade_as_user_id($user_id);

    header("Location: " . get_base_url());
}


// send out an email to selected users
function email_users() {

    //TODO: this whole function
    flash_message_cb_and_exit('show_users', _('Users emailed.'));
}


// unlock selected user accounts
function unlock_users() {

    $count = 0;
    // TODO: unlock stuff - reset login_times and all that jazz
    flash_message_cb_and_exit('show_users', sprintf(_('%d user accounts unlocked successfully.'), $count));
}


// disable selected user accounts
function disable_users() {

    $count = users_set_user_attr('enabled', 0);
    flash_message_cb_and_exit('show_users', sprintf(_('%d user accounts disabled successfully.'), $count));
}


// enable selected user accounts
function enable_users() {

    $count = users_set_user_attr('enabled', 1);
    flash_message_cb_and_exit('show_users', sprintf(_('%d user accounts enabled successfully.'), $count));
}


// used to adjust user attributes in bulk via the user_id request var
function users_set_user_attr($attr, $value) {

    check_nagios_session_protector();

    $user_id = users_get_request_user_id();

    $count = 0;

    // attempt to enable/disable
    if (is_array($user_id)) {
        foreach ($user_id as $this_user_id) {
            if (is_valid_user_id($this_user_id)) {
                set_user_attr($attr, $value, $this_user_id);
                $count++;
            }
        }
    } else {
        if (is_valid_user_id($user_id)) {
            set_user_attr($attr, $value, $user_id);
            $count++;
        }
    }

    // return the count so the calling function can print the message
    return $count;
}


// delete selected user accounts
function delete_users() {

    check_nagios_session_protector();

    $user_id = users_get_request_user_id();

    $deleted_user_count = 0;

    // attempt to delete
    if (is_array($user_id)) {
        foreach ($user_id as $this_user_id) {
            if (delete_user($this_user_id))
                $deleted_user_count++;
        }
    } else {
        if (delete_user($user_id))
            $deleted_user_count++;
    }

    flash_message_cb_and_exit('show_users', sprintf(_('%d users successfully deleted!'), $deleted_user_count));
}


// create or update a user account
function update_user() {

    check_nagios_session_protector();

    // if we aren't updating or we pressed cancel then just go ahead and show_users
    $update = grab_request_var('update', false);
    $cancel = grab_request_var('cancel', false);
    if (!$update || $cancel)
        flash_message_cb_and_exit('show_users');

    // grab the user id, but intval it to be safe
    $user_id = intval(grab_request_var('user_id', -1));
    $add_user = ($user_id == -1);

    // get our submitted data
    $username = grab_request_var('username');
    $password1 = grab_request_var('password1');
    $password2 = grab_request_var('password2');
    $force_password_change = grab_request_var('force_password_change');
    $email_account_info = grab_request_var('email_account_info');
    $name = grab_request_var('name');
    $email = grab_request_var('email');
    $language = grab_request_var('language');
    $date_format = grab_request_var('date_format');
    $number_format = grab_request_var('number_format');
    $account_enabled = grab_request_var('account_enabled');
    $user_mapping = grab_request_var('user_mapping');
    $server_exclusion = grab_request_var('server_exclusion');

    $level = grab_request_var('level');
    if ($username == 'nagiosadmin')
        $level = 1; // can't turn this off, sorry buddy

    // adding or updating?
    if ($add_user) {

        // adding user

        $errmsg = '';
        if (empty($username))
            $errmsg .= _('You must enter a username.') . '<br>';
        if (empty($name))
            $errmsg .= _('You must enter a name.') . '<br>';
        if (empty($email))
            $errmsg .= _('You must enter an email address.') . '<br>';
        if (empty($password1))
            $errmsg .= _('You must enter a valid password.') . '<br>';
        if ($password1 != $password2)
            $errmsg .= _('Passwords must match.') . '<br>';
        if (!empty($username) && get_user_id($username))
            $errmsg .= _('User with that username already exists.') . '<br>';
        if (!preg_match('/^[A-Za-z0-9\_\-]*$/', $username))
            $errmsg .= _('Usernames may only contain alphanumeric characters, an underscore (_) or a hyphen (-).');

        if (!empty($errmsg))
            flash_message_cb_and_exit('edit_user', $errmsg, 'error');

        $user_id = add_user($username, $password1, $name, $email, $account_enabled, $level);

        if ($user_id !== false) {

            set_user_meta('force_password_change', $force_password_change, false, $user_id);
            set_user_meta('language', $language, false, $user_id);
            set_user_meta('date_format', $date_format, false, $user_id);
            set_user_meta('number_format', $number_format, false, $user_id);

            flash_message(_('User added successfully!'));

        } else {

            flash_message(_('Something went wrong adding user.'), 'error');
        }

    } else {

        // updating
        set_user_attr('username', $username, $user_id);

        if (!empty($password1) && $password1 == $password2)
            set_user_attr('password', hash('sha256', $password1), $user_id);

        set_user_attr('name', $name, $user_id);
        set_user_attr('email', $email, $user_id);
        set_user_attr('enabled', $account_enabled, $user_id);
        set_user_attr('level', $level, $user_id);

        set_user_meta('force_password_change', $force_password_change, false, $user_id);
        set_user_meta('language', $language, false, $user_id);
        set_user_meta('date_format', $date_format, false, $user_id);
        set_user_meta('number_format', $number_format, false, $user_id);

        // user mapping
        foreach ($user_mapping as $server_id => $username) {

            if ($username == 'none')
                delete_current_mapped_user($server_id, $user_id);
            else
                set_current_mapped_user($server_id, $username, $user_id);
        }

        // server exclusions
        $all_servers = get_servers(true, $include_exclusions = false);
        foreach ($all_servers as $server) {
            $server_id = $server['server_id'];

            if (empty($server_exclusion[$server_id]))
                remove_user_server_exclusion($server_id, $user_id);
            else
                set_user_server_exclusion($server_id, $user_id);
        }

        flash_message(_('User Updated!'));
    }

    // send email if required
    if (!empty($email_account_info)) {

        $password = $password1;
        $adminname = get_option('admin_name');
        $adminemail = get_option('admin_email');
        $internal_url = get_option('internal_url');

        $message = _('An account has been created for you to access Nagios Fusion. You can login using the following information:') . "\n";
        if (!$add_user)
            $message = _('You can login to Nagios Fusion using the following information:') . "\n";

        $message .= '    ' . _('Username') . ': ' . $username . "\n";
        $message .= '    ' . _('Password') . ': ' . $password . "\n";
        $message .= '    ' . _('URL') . ': ' . $internal_url . "\n";

        // Set where email is coming from for PHPmailer log
        $send_mail_referer = 'admin/users.php > Account Creation';

        $opts = array(
            'from' => $adminname . ' <' . $adminemail . ">\r\n",
            'to' => $email,
            'subject' => _('Nagios Fusion Account Created'),
            'message' => $message,
        );

        send_email($opts, $debugmsg, $send_mail_referer);
    }

    header("Location: users.php");
}


// show the users list and buttons to manipulate user accounts
function show_users() {

    $title = _('Manage Users');
    child_page($title);
    echo well_top_page_header($title);
    ?>

    <div class="page-buttons">
        <a href="?edit" class="btn btn-sm btn-primary">
            <i class="fa fa-user-plus"></i>
            <span><?php echo _('Add New User'); ?></span>
        </a>
    </div>

    <?php
    $select_statement = "SELECT user_id, username, name, email, enabled, account_locked FROM users";
    $opts = array(
        'display_footer' => false,
        'table_class' => 'table table-condensed table-hover table-bordered table-striped',
        'pre_table_html' => 
            '<script>
                $(function() { 
                    $("#select_all").click(function() { 
                        $("input.users_checkbox").prop("checked", $(this).prop("checked")); 
                    }); 
                    $("input.users_checkbox").closest("tr").click(function(ev) {                        
                        // cancel if click is on an input or on a th
                        if (ev.target.nodeName === "INPUT" || ev.target.nodeName === "TH" || ev.target.nodeName === "IMG" || ev.target.nodeName == "SPAN")
                            return;

                        $(this).find("input.users_checkbox").click();
                    });
                    $("a.action_button.delete.user").click(function() {
                        return confirm("' . _('Are you sure you want to delete this user?') . '");
                    });
                    $("button.delete").click(function() {
                        return confirm("' . _('Are you sure you want to delete these users?') . '");
                    });
                });
            </script>',

        'columns' => array(
            'checkbox' => array(
                'th' => '<input type="checkbox" id="select_all" class="users_checkbox" />',
                'td' => '<input type="checkbox" name="user_id[]" value="%user_id%" class="users_checkbox" />',
                'replace_macros' => true,
                'width' => '16px',
                ),
            'username' => array(
                'th' =>  _('Username'),
                'sortable' => true,
                'width' => '25%',
                ), 
            'name' => array(
                'th' =>  _('Name'),
                'sortable' => true,
                ),
            'email' => array(
                'sortable' => true,
                'th' => _('Email'),
                ),
            'actions' => array(
                'th' => _('Actions'),
                'transform' => 'users_build_action_td',
                'replace_macros' => true,
                ),
            ),
        'with_selected' => array(
            array(
                'value' => 'delete',
                'class' => 'delete',
                'title' => _('Delete'),
                'img' => get_icon_url('cross.png'),
                ),
            /*array(
                'type' => 'button',
                'title' => _('Send Emails'),
                'img' => get_icon_url('email_go.png'),
                'onclick' => 'users_display_email_selected(false);',
                ),*/
            array(
                'value' => 'enable',
                'title' => _('Enable'),
                'img' => get_icon_url('user_add.png'),
                ),
            array(
                'value' => 'disable',
                'title' => _('Disable'),
                'img' => get_icon_url('user_disable.png'),
                ),
            /*array(
                'value' => 'unlock',
                'title' => _('Unlock'),
                'img' => get_icon_url('lock_open.png'),
                ),*/
            ),
        );
    echo '<form method="post">';
    echo get_paged_table($select_statement, null, $opts);
    echo '</form>';
}


// edit/add user account
function edit_user() {

    $title = _('Manage User');
    child_page($title);

    // i just met you, and this is crazy, but heres a valid user_id, or add me maybe?
    // user_id of -1 means add, otherwise edit
    $user_id = users_get_request_user_id($return_int_only = true);

    // just to help with readability
    $add_user = $user_id == -1 ? true : false;

    // set some of the displays based on whether we're adding or editing
    $page_header = $add_user ? _('Create User') : _('Edit User');
    $submit_button_value = $add_user ? _('Add User') : _('Update User');

    // get our user data or defaults
    $username = get_user_attr('username', $user_id, '');
    $username = grab_request_var('username', $username);
    
    $force_password_change = get_user_meta('force_password_change', 1, $user_id);
    $force_password_change = grab_request_var('force_password_change', $force_password_change);
    
    $name = get_user_attr('name', $user_id, '');
    $name = grab_request_var('name', $name);
    
    $email = get_user_attr('email', $user_id, '');
    $email = grab_request_var('email', $email);

    $email_account_info = grab_request_var('email_account_info', false);
    
    $language = get_option('default_language', 'en_US');
    $language = get_user_meta('language', $language, $user_id);
    $language = grab_request_var('language', $language);
    
    $date_format = get_option('default_date_format', DF_ISO8601);
    $date_format = get_user_meta('date_format', $date_format, $user_id);
    $date_format = grab_request_var('date_format', $date_format);    

    $number_format = get_option('default_number_format', NF_2);
    $number_format = get_user_meta('number_format', $number_format, $user_id);
    $number_format = grab_request_var('number_format', $number_format);
    
    $account_enabled = get_user_attr('enabled', $user_id, 1);
    $account_enabled = grab_request_var('account_enabled', $account_enabled);

    $level = get_user_attr('level', $user_id, USER_LEVEL_NONPRIV);
    $level = grab_request_var('level', $level);

    $timezone = get_user_meta('timezone', date_default_timezone_get(), $user_id);
    $timezone = grab_request_var('timezone', $timezone);
    
    get_timezones_and_selected($timezones, $timezone);

    $password = '';
    if ($add_user)
        $password = random_string(10);

    echo well_top_page_header($page_header);

    $req = '';
    if ($add_user) 
        $req = 'required="true"';
    ?>

<?php if (!$add_user) { ?>
<script type="text/javascript">
    $(function() {
        $('#password1').change(function() {
            if ($(this).val() == '') {
                remove_dynamic_required($('#password2'));
            } else {
                set_dynamic_required($('#password2'));
            }
        });
        $('#password2').change(function() {
            if ($(this).val() == '') {
                remove_dynamic_required($('#password1'));
            } else {
                set_dynamic_required($('#password1'));
            }
        });
    });
</script>
<?php } ?>
<form method="post" action="?update" class="formbuilder" >
    <input name="update"  value="1"  type="hidden"  />

    <?php
    if (!$add_user) {
    ?>
        <input name="user_id"  value="<?php echo $user_id; ?>"  type="hidden"  />
    <?php
    } // if !add_user
    ?>

    <div class="formbuilder-div formbuilder" >
        <h5 class="ul" >
            <?php echo _('General Settings'); ?>
        </h5>
        <table class="formbuilder-table formbuilder" >
            <tr>
                <td>
                    <label for="username" >
                        <?php echo _('Username'); ?>:
                    </label>
                </td>
                <td>
                    <input name="username"  placeholder="Username"  value="<?php echo encode_html($username); ?>"  type="text"  id="username"  class="form-control textfield" required="true" />
                    <div class="subtext">
                        <?php echo _('Usernames may only contain alphanumeric characters, an underscore (_) or a hyphen (-).'); ?>
                    </div>
                </td>
            </tr>
            <tr>
                <td>
                    <label for="password1" >
                        <?php echo _('Password'); ?>:
                    </label>
                </td>
                <td>
                    <input name="password1"  type="password"  id="password1"  class="form-control textfield" <?php echo encode_html($req); ?> />
                </td>
            </tr>
            <tr>
                <td>
                    <label for="password2" >
                        <?php echo _('Repeat Password'); ?>:
                    </label>
                </td>
                <td>
                    <input name="password2"  type="password"  id="password2"  class="form-control textfield" <?php echo encode_html($req); ?> />
                </td>
            </tr>
            <tr>
                <td>
                    <label for="name" >
                        <?php echo _('Name'); ?>:
                    </label>
                </td>
                <td>
                    <input name="name"  placeholder="First Last"  value="<?php echo encode_html($name); ?>"  type="text"  id="name"  class="form-control textfield"  required="true"  />
                </td>
            </tr>
            <tr>
                <td>
                    <label for="email" >
                        <?php echo _('Email Address'); ?>:
                    </label>
                </td>
                <td>
                    <input name="email"  placeholder="email@address.com"  value="<?php echo encode_html($email); ?>"  type="email"  id="email"  class="form-control textfield"  required="true"   />
                </td>
            </tr>
            <tr>
                <td>
                    <label for="level" >
                        <?php echo _('Administrator'); ?>:
                    </label>
                </td>
                <td>
                    <input name="level"  type="checkbox"  value="1" <?php is_checked($level); ?> id="level"  class="checkbox"  />
                </td>
            </tr>
            <tr>
                <td>
                    <label for="account_enabled" >
                        <?php echo _('Account Enabled'); ?>:
                    </label>
                </td>
                <td>
                    <input name="account_enabled"  type="checkbox"  value="1" <?php is_checked($account_enabled); ?> id="account_enabled"  class="checkbox"  />
                </td>
            </tr>
            <tr>
                <td>
                    <label for="email_account_info" >
                        <?php echo _('Email User Account Information'); ?>:
                    </label>
                </td>
                <td>
                    <input name="email_account_info"  type="checkbox"  value="1" <?php is_checked($email_account_info); ?> id="email_account_info"  class="checkbox"  />
                </td>
            </tr>
            <tr>
                <td>
                    <label for="force_password_change" >
                        <?php echo _('Force Password Change at Next Login'); ?>:
                    </label>
                </td>
                <td>
                    <input name="force_password_change"  type="checkbox"  value="1" <?php is_checked($force_password_change); ?> id="force_password_change"  class="checkbox"  />
                </td>
            </tr>
        </table>
    </div>
    <?php

    // server user mapping!
    $count_servers = count_servers(false);
    if ($count_servers !== false && $count_servers > 0) {

        ?>
        <div class="formbuilder-div formbuilder" style="min-height: 370px;">
            <h5 class="ul" >
                <?php echo _('Server User Mapping'); ?>
            </h5>
            <table class="formbuilder-table formbuilder" >
        <?php

        $servers = get_servers(false);

        foreach ($servers as $server) {

            $users = false;
            $selected_user = false;
            $server_excluded = get_user_server_exclusion($server, $user_id);

            $element_id = random_string(10);
            $exclude_id = random_string(10);

            // we only give them a mapping option if they are using fusekey
            if ($server['authentication_type'] == AUTH_TYPE_FUSEKEY) {

                $users = get_server_users($server['server_id'], 'none', _('No Mapping'));
                if ($users !== false) {

                    $selected_user = get_current_mapped_user($server['server_id'], $user_id);
                    if (is_null($selected_user))
                        $selected_user = 'none';
                }
            }

            ?>

            <tr>
                <td>
                    <label for="<?php echo $element_id; ?>" >
                        <?php echo $server['name']; ?>
                    </label>
                </td>
                <td>
                    <?php
                    if (is_array($users)) {
                    ?>
                        <select name="user_mapping[<?php echo $server['server_id'] ?>]"  id="<?php echo $element_id; ?>"  class="dropdown form-control" >
                            <?php echo get_options_from_array($users, $selected_user); ?>
                        </select>
                    <?php
                    } else {
                    ?>
                        <input disabled="disabled"  value="<?php echo $server['username']; ?>"  type="text"  id="<?php echo $element_id; ?>"  class="form-control textfield"  />
                        <div class="subtext">
                            <?php
                                // we output a little bit of information depending on the server type here
                                if ($server['server_type'] == SERVER_TYPE_XI) {
                                    echo _("You are only able map specific users on XI servers that have utilize a Fusekey.");

                                } else if ($server['server_type'] == SERVER_TYPE_CORE) {
                                    echo _("You are not able to map users on Core servers.");
                                }
                            ?>
                        </div>
                    <?php
                    } // if is_array(users) or ELSE..
                    ?>
                </td>
            </tr>
            <tr>
                <td></td>
                <td>
                    <input id="<?php echo $exclude_id; ?>"  value="1"  name="server_exclusion[<?php echo $server['server_id'] ?>]"  style="float: left; margin-top: 3px" 
                        type="checkbox"  class="checkbox" <?php is_checked($server_excluded); ?> />
                    <label for="<?php echo $exclude_id; ?>" style="font-weight: normal; display: inline-block; margin-top: 1px;">&nbsp;Exclude user from seeing server data</span>
                </td>
            </tr>
            <tr>
                <td colspan="2"></td>
            </tr>

            <?php

        } // foreach servers
        ?>

            </table>
        </div>
        <?php
    } // if count servers > 0

    ?>
    <div class="formbuilder-div formbuilder" >
        <h5 class="ul" >
            <?php echo _('Preferences'); ?>
        </h5>
        <table class="formbuilder-table formbuilder" >
            <tr>
                <td>
                    <label for="language" >
                        <?php echo _('Language'); ?>:
                    </label>
                </td>
                <td>
                    <select name="language"  id="language"  class="dropdown form-control" >
                        <?php echo get_options_from_array(get_languages_as_array(), $language); ?>
                    </select>
                </td>
            </tr>
            <tr>
                <td>
                    <label for="date_format" >
                        <?php echo _('Date Format'); ?>:
                    </label>
                </td>
                <td>
                    <select name="date_format"  id="date_format"  class="dropdown form-control" >
                        <?php echo get_options_from_array(get_date_formats_as_array(), $date_format); ?>
                    </select>
                </td>
            </tr>
            <tr>
                <td>
                    <label for="timezone" >
                        <?php echo _('Timezone'); ?>:
                    </label>
                </td>
                <td>
                    <select name="timezone"  id="timezone"  class="dropdown form-control" >
                        <?php echo get_options_from_array($timezones, $timezone); ?>
                    </select>
                </td>
            </tr>
            <tr>
                <td>
                    <label for="number_format" >
                        <?php echo _('Number Format'); ?>:
                    </label>
                </td>
                <td>
                    <select name="number_format"  id="number_format"  class="dropdown form-control" >
                        <?php echo get_options_from_array(get_number_formats_as_array(), $number_format); ?>
                    </select>
                </td>
            </tr>
        </table>
    </div>
    <div class="clear"></div>
    <div class="formbuilder-buttons">
        <input name="submit"  value="<?php echo $submit_button_value; ?>"  class="btn btn-primary btn-sm"  type="submit"  />
        <input name="cancel"  value="<?php echo _('Cancel'); ?>"  class="btn btn-default btn-sm cancel-validator"  type="submit"  />
    </div>
</form>
    <?php
}


// generic function for grabbing the user_id request var
// you can either get a single integer or an array for editting
// this function checks for user_id validity
function users_get_request_user_id($return_int_only = false) {

    // get the request user_id
    $user_id = grab_request_var('user_id', -1);

    // if we only want an int, that means we want the first of the array
    if ($return_int_only && is_array($user_id)) {

        $user_id = current($user_id);
 
    } else if (is_array($user_id)) {

        // check for valid user ids
        foreach ($user_id as $key => $uid) {

            if (!is_valid_user_id($uid))
                unset($user_id[$key]);
        }

        return $user_id;
    }

    // if we made it this far we need to double check that its a valid user_id
    if (is_valid_user_id($user_id))
        return $user_id;

    // return a -1 for all other cases
    return -1;
}
