<?php

function fusioncore_poll_alerts(&$raw_data, $server = '') {

    $server = get_server($server);
    if ($server === false)
        return array();

    $alert_data = array();

    $xi = false;
    $core = false;

    // xi
    if (!empty($raw_data['logentries']['logentry'])) {
        $xi = true;
        $alerts = $raw_data['logentries']['logentry'];

        if ($raw_data['logentries']['recordcount'] == 1)
            $alerts = array($alerts);
    }

    // core
    if (!empty($raw_data['data']['alertlist'])) {
        $core = true;
        $alerts = $raw_data['data']['alertlist'];
    }

    // have to let the poller know we're not the one..
    if (!$xi && !$core)
        return null;
    
    foreach ($alerts as $alert) {

        $time = null;
        $type = null;
        $host = null;
        $service = null;
        $state_type = null;
        $state = null;
        $output = null;

        // xi comes back from mysql datetime in the server's timezone
        // core is already epoch
        if (isset($alert['entry_time']))
            $time = convert_server_timestring_to_local_timestring($server, $alert['entry_time']);
        if (isset($alert['timestamp']))
            $time = date('Y-m-d H:i:s', substr($alert['timestamp'], 0, -3)); // core is in microseconds

        if (isset($alert['logentry_type']))
            $type = $alert['logentry_type'];

        // xi looks like: "SERVICE ALERT: HP48SW-01.nagios.local;Port 11 Status;CRITICAL;SOFT;1;CRITICAL: Interface 11 (index 11) is down."
        // so we break on the first :, and then explode on ; to get the parts of data we need
        if (isset($alert['logentry_data'])) {

            if (($colon_pos = strpos($alert['logentry_data'], ':')) !== false) {

                $logentry = substr($alert['logentry_data'], $colon_pos + 1);
                $logentry = explode(';', $logentry);

                $element = 0;

                if (!empty($logentry[$element]))
                    $host = trim($logentry[$element++]);

                // if this is a service?
                if (count($logentry) == 6 && !empty($logentry[$element]))
                    $service = trim($logentry[$element++]);

                if (!empty($logentry[$element]))
                    $state = trim($logentry[$element++]);

                if (!empty($logentry[$element]))
                    $state_type = trim($logentry[$element++]);

                // the next one is the count. we do nothing with that
                $element++;

                if (!empty($logentry[$element]))
                    $output = trim($logentry[$element]);
            }
        }

        if (isset($alert['host_name']))
            $host = $alert['host_name'];
        if (isset($alert['name']))
            $host = $alert['name'];

        if (isset($alert['description']))
            $service = $alert['description'];

        if (isset($alert['state']))
            $state = $alert['state'];

        if (isset($alert['state_type']))
            $state_type = $alert['state_type'];

        if (isset($alert['plugin_output']))
            $output = $alert['plugin_output'];

        // we need a type to store from core data
        if ($core) {

            if ($state_type == AU_STATETYPE_HARD)
                $state_type = 'HARD';
            else if ($state_type == AU_STATETYPE_SOFT)
                $state_type = 'SOFT';

            switch($state) {
                case AU_STATE_HOST_UP:
                    $type = NSLOG_HOST_UP;
                    $state = 'UP';
                    break;

                case AU_STATE_HOST_DOWN:
                    $type = NSLOG_HOST_DOWN;
                    $state = 'DOWN';
                    break;
                
                case AU_STATE_HOST_UNREACHABLE:
                    $type = NSLOG_HOST_UNREACHABLE;
                    $state = 'UNREACHABLE';
                    break;
                
                case AU_STATE_SERVICE_OK:
                    $type = NSLOG_SERVICE_OK;
                    $state = 'OK';
                    break;
                
                case AU_STATE_SERVICE_WARNING:
                    $type = NSLOG_SERVICE_WARNING;
                    $state = 'WARNING';
                    break;
                
                case AU_STATE_SERVICE_CRITICAL:
                    $type = NSLOG_SERVICE_CRITICAL;
                    $state = 'CRITCAL';
                    break;
                
                case AU_STATE_SERVICE_UNKNOWN:
                    $type = NSLOG_SERVICE_UNKNOWN;
                    $state = 'UNKNOWN';
                    break;
            }
        }
  
        if (!empty($host) && !empty($time)) 
            $alert_data[] = array(
                'time' => $time,
                'type' => $type,
                'host' => $host,
                'service' => $service,
                'state_type' => $state_type,
                'state' => $state,
                'output' => $output,
                );
    }

    return array('alert_list' => $alert_data);
}
