<?php
require_once(dirname(__FILE__) . '/../base.inc.php');


/* basic pageparts functions to format text for us */
function pageparts_include_url($base_url, $build_id, $url) { return $base_url . $url . '?' . $build_id; }
function pageparts_include_javascript($url) { echo "\n\t\t" . '<script type="text/javascript" src="' . $url . '"></script>'; }
function pageparts_include_stylesheet($url) { echo "\n\t\t" . '<link rel="stylesheet" href="' . $url . '" type="text/css" />'; }


/**
 * parent_page() - main driver for parent pages (the corresponding bottom will automatically be printed when the script finishes executing)
 * @param string $page_title - the title to set for the page
 * @param string $page - the specified page (corresponding to the menu object) to print the menu items for
 * @param string $iframe_src - the value to set as the src in the maincontent iframe
 * @param array $opts - options, see reference in phpdoc for print_page_top()
 * @param bool $autocomplete_page_bottom - you want the bottom of this page to be automagically printed for you? true or false?
 * @param bool $product_in_page_title - include the product name in the page_title. true by default
 */
function parent_page($page_title, $page, $iframe_src, $opts = array(), $autocomplete_page_bottom = true, $product_in_page_title = true) {

    print_parent_page_top($page_title, $page, $iframe_src, $opts, $autocomplete_page_bottom, $product_in_page_title);
}


/**
 * print_parent_page_bottom() - driver function for printing page top of parent pages
 * @param string $page_title - the title to set for the page
 * @param string $page - the specified page (corresponding to the menu object) to print the menu items for
 * @param array $opts - options, see reference in phpdoc for print_page_top()
 * @param bool $autocomplete_page_bottom - you want the bottom of this page to be automagically printed for you? true or false?
 * @param bool $product_in_page_title - include the product name in the page_title. true by default
 */
function print_parent_page_top($page_title, $page, $iframe_src, $opts = array(), $autocomplete_page_bottom = true, $product_in_page_title = true) {
    
    $child = false;

    if ($product_in_page_title)
        $page_title = $page_title . ' &middot; ' . get_product_name();

    if (!is_array($opts)) {
        $opts = array();
    }
    $opts['iframe_src'] = $iframe_src;

    print_page_top($page_title, $page, $child, $opts);

    if ($autocomplete_page_bottom) {
        register_shutdown_function('print_parent_page_bottom');
    }
}


/**
 * print_parent_page_bottom() - driver function for printing page bottom of parent pages
 */
function print_parent_page_bottom() {

    $child = false;

    print_page_bottom($child);
}


/**
 * child_page() - main driver for child pages (the corresponding bottom will automatically be printed when the script finishes executing)
 * @param string $page_title - the title to set for the page
 * @param array $opts - options, see reference in phpdoc for print_page_top()
 * @param string $page - the specified page (corresponding to the menu object) to print the menu items for
 */
function child_page($page_title, $opts = array(), $page = null) {

    print_child_page_top($page_title, $opts, $page);
}


/**
 * print_child_page_bottom() - driver function for printing page top of child pages
 * @param string $page_title - the title to set for the page
 * @param array $opts - options, see reference in phpdoc for print_page_top()
 * @param string $page - the specified page (corresponding to the menu object) to print the menu items for
 * @param bool $autocomplete_page_bottom - you want the bottom of this page to be automagically printed for you? true or false?
 */
function print_child_page_top($page_title, $opts = array(), $page = null, $autocomplete_page_bottom = true) {

    $child = true;

    print_page_top($page_title, $page, $child, $opts);

    if ($autocomplete_page_bottom) {
        register_shutdown_function('print_child_page_bottom');
    }
}


/**
 * print_child_page_bottom() - driver function for printing page bottom of child pages
 */
function print_child_page_bottom() {

    $child = true;

    print_page_bottom($child);
}


/**
 * print_page_top() - print the beginning html of any page
 * @param string $page_title - the title to set for the page
 * @param string $page - the specified page (corresponding to the menu object) to print the menu items for
 * @param bool $child - this is a child? true or false?
 * @param array $opts optional - checks for a few elements, such as page_id, page_class, iframe_src
 */
function print_page_top($page_title, $page, $child, $opts = array()) {

    $dont_display_the_iframe_on_these_pages = array(
        'login.php',
        'install.php',
    );

    $child = (bool) $child;
    $parent = !$child;

    $cbargs = array('child' => $child);

    $logo = 'fusion-logo-small.png';
    $base_url = get_base_url();
    $build_id = get_build_id();
    $current_page = get_current_page();

    $body_class = ($child) ? 'child' : 'parent';
    if (!empty($opts['body_class'])) {
        $body_class .= ' ' .$opts['body_class'];
    }
    $body_class = ' class="' . $body_class . '" ';

    $body_style = '';
    if (!empty($opts['body_style'])) {
        $body_style = ' style="'. $opts['body_style'] . '"';
    }

    $page_id = '';
    if (!empty($opts['page_id']))
        $page_id = ' id="' . $opts['page_id'] . '" ';

    $page_class = ($child) ? 'childpage' : 'parentpage';
    if (!empty($opts['page_class']))
        $page_class .= ' ' . $opts['page_class'];
    $page_class = ' class="' . $page_class . '" ';

    $header_id = ($child) ? 'childheader' : 'header';
    $header_id = ' id="' . $header_id . '" ';

    $header_class = ($child) ? 'childhead' : 'parenthead';
    $header_class = ' class="' . $header_class . '" ';

    $show_license = false;
    if (@isset($opts['show_license']) && $opts['show_license'] == true)
        $show_license = true;

    // Fusion window and frame source
    $iframe_src = 'home.php';
    if (!empty($opts['iframe_src'])) {
        $iframe_src = $opts['iframe_src'];
    }

    // Clean up fusionwindow to not have "http" or "file" etc
    $iframe_src = grab_request_var('fusionwindow', $iframe_src);
    if (strpos($iframe_src, "//")) {
        $x = explode('//', $iframe_src);
        if (isset($x[1])) {
            $iframe_src = $x[1];
        } else {
            $iframe_src = '';
        }
    }

    // Do a quick check to see if we are supposed to display the iframe
    $display_iframe = true;
    foreach ($dont_display_the_iframe_on_these_pages as $p) {
        if (strpos($current_page, $p) !== false) {
            $display_iframe = false;
        }
    }

    $flash_message = $child ? get_flash_message() : '';
    ?>

<!DOCTYPE html>
<html>
    <head>
        <title><?php echo $page_title; ?></title>
        <meta name="ROBOTS" content="NOINDEX, NOFOLLOW" />
        <meta http-equiv="Content-Type" content="text/html; charset=UTF-8" />
        <link rel="shortcut icon" href="<?php echo $base_url; ?>/static/images/icons/favicon.ico?<?php echo $build_id; ?>" type="image/ico" />

        <script type="text/javascript">
            var base_url = "<?php echo $base_url; ?>";
            var ajax_helper_url = "<?php echo $base_url . "ajaxhelper.php" ?>";
            var permalink_base = "<?php echo urlencode(get_permalink_base()); ?>";
            var nsp_str = "<?php echo get_nagios_session_protector_id();?>";
        </script>

        <?php
        pageparts_include_stylesheet(pageparts_include_url($base_url, $build_id, 'static/css/normalize.css'));
        pageparts_include_javascript(pageparts_include_url($base_url, $build_id, 'static/js/jquery/jquery-1.12.4.min.js'));
        pageparts_include_javascript(pageparts_include_url($base_url, $build_id, 'static/js/jquery/jquery.tablesorter.js'));
        
        // color picker!
        pageparts_include_javascript(pageparts_include_url($base_url, $build_id, 'static/js/spectrum.js'));
        pageparts_include_stylesheet(pageparts_include_url($base_url, $build_id, 'static/css/spectrum.css'));

        pageparts_include_stylesheet(pageparts_include_url($base_url, $build_id, 'static/css/font-awesome.min.css'));


        pageparts_include_javascript(pageparts_include_url($base_url, $build_id, 'static/js/jquery/jquery-ui-1.12.1.custom.min.js'));
        pageparts_include_stylesheet(pageparts_include_url($base_url, $build_id, 'static/js/jquery/css/smoothness/jquery-ui.custom.min.css'));

        pageparts_include_javascript(pageparts_include_url($base_url, $build_id, 'static/js/jquery/jquery.colorBlend.js'));

        pageparts_include_javascript(pageparts_include_url($base_url, $build_id, 'static/js/jquery/jquery.timers-1.1.3.js'));
        pageparts_include_stylesheet(pageparts_include_url($base_url, $build_id, 'static/css/jquery.autocomplete.css'));

        pageparts_include_javascript(pageparts_include_url($base_url, $build_id, 'static/js/bootstrap.3.min.js'));
        pageparts_include_stylesheet(pageparts_include_url($base_url, $build_id, 'static/css/bootstrap.3.min.css'));

        pageparts_include_javascript(pageparts_include_url($base_url, $build_id, 'static/js/core.js'));
        pageparts_include_javascript(pageparts_include_url($base_url, $build_id, 'static/js/themes/modern.js'));


        pageparts_include_stylesheet(pageparts_include_url($base_url, $build_id, 'static/css/base.css'));        
        pageparts_include_stylesheet(pageparts_include_url($base_url, $build_id, 'static/css/themes/modern.css'));
        
        pageparts_include_javascript(pageparts_include_url($base_url, $build_id, 'static/js/dashlets.js'));
        pageparts_include_stylesheet(pageparts_include_url($base_url, $build_id, 'static/css/dashlets.css'));
        pageparts_include_stylesheet(pageparts_include_url($base_url, $build_id, 'static/css/spinkit.css'));

        pageparts_include_javascript(pageparts_include_url($base_url, $build_id, 'static/js/views.js'));
        pageparts_include_javascript(pageparts_include_url($base_url, $build_id, 'static/js/clipboard.min.js'));

        pageparts_include_javascript(pageparts_include_url($base_url, $build_id, 'static/js/highcharts/highcharts.js'));
        pageparts_include_javascript(pageparts_include_url($base_url, $build_id, 'static/js/highcharts/highcharts-more.js'));
        pageparts_include_javascript(pageparts_include_url($base_url, $build_id, 'static/js/highcharts/modules/exporting.js'));
        pageparts_include_javascript(pageparts_include_url($base_url, $build_id, 'static/js/highcharts/modules/no-data-to-display.js'));
        //pageparts_include_javascript(pageparts_include_url($base_url, $build_id, 'static/js/highcharts/themes/gray.js'));
?>

        <script type="text/javascript">
            $(function() {
                $('form').each(function(form_index, form) {
                    if ($(form).children("input[name='nsp']").length > 0) {
                        $(form).children("input[name='nsp']").each(function(input_index, input) {
                            $(input).val('<?php echo get_nagios_session_protector_id(); ?>');
                        });
                    } else {
                        $(form).append('<?php echo get_nagios_session_protector(); ?>');
                    }
                });
            });
        </script>

    </head>
    <body <?php echo $body_class . $body_style; ?>>

    <?php 
    if ($parent) {
        echo get_screen_dashboard_html(); 
    }
    ?>

    <?php echo $flash_message; ?>

    <div <?php echo $page_id . ' ' . $page_class; ?>>

        <div id="whiteout"></div>
        <div id="blackout"></div>

        <div id="throbber" class="sk-spinner sk-spinner-center sk-spinner-three-bounce">
            <div class="sk-bounce1"></div>
            <div class="sk-bounce2"></div>
            <div class="sk-bounce3"></div>
        </div>

        <div <?php echo $header_id . ' ' . $header_class; ?>>

            <?php print_page_header_content($child); ?>

        </div><!-- header -->

        <?php
        if (is_authenticated()) {
            license_check_content_header($child);
        }
        ?>

        <?php
        if ($parent) {
            if ($display_iframe) {
        ?>

            <div id="mainframe">
                <div id="leftnav">

                    <?php 
                    global $menu;
                    init_menu($page);
                    $menu->print_menu($page);
                    ?>

                </div><!-- leftnav -->
                <div id="maincontent">
                    <iframe src="<?php echo encode_html($iframe_src); ?>" width="100%" frameborder="0" id="maincontentframe" name="maincontentframe">
                        [Your user agent does not support frames or is currently configured not to display frames. ]
                    </iframe>
                </div>
            </div><!-- mainframe -->

            <?php 
            } // $display_iframe
                    
        } // $parent
}


/**
 * print_page_header_content() - perform callbacks and print the header content
 * @param bool $child - this is a child? true or false?
 */
function print_page_header_content($child) {

    $cbargs = array('child' => $child);

    do_callbacks(CALLBACK_HEADER_START, $cbargs);

    if ($child) {
        include_once(dirname(__FILE__) . '/header.child.inc.php');
    } else {
        include_once(dirname(__FILE__) . '/header.parent.inc.php');
    }

    do_callbacks(CALLBACK_HEADER_END, $cbargs);
}



/**
 * print_page_bottom() - perform callbacks, print footers, wrap up remaining html
 * @param bool $child - this is a child? true or false?
 */
function print_page_bottom($child) {

    $cbargs = array('child' => $child);

    do_callbacks(CALLBACK_FOOTER_START, $cbargs);

    if ($child) {
        include_once(dirname(__FILE__) . '/footer.child.inc.php');
    } else {
        include_once(dirname(__FILE__) . '/footer.parent.inc.php');
    }

    do_callbacks(CALLBACK_FOOTER_END, $cbargs);

    ?>

    <?php if (!$child && !is_authenticated()) { ?>

            </div><!-- mainframe -->
    <?php } ?>

    </div><!-- page div -->
    </body>
    </html>

    <?php
}
