<?php

function set_language($language)
{
    ini_set('default_charset', 'UTF-8');
    $langdir = '/usr/local/nagiosfusion/html/includes/lang/locale/';

    // Fix for wrong en_US language name (en and en_EN)
    if ($language == 'en' || $language == 'en_EN') {
        $language = 'en_US';
    }

    // Only set gettext (now _()) locale if we have a language file
    if (!file_exists($langdir . $language)) {
        return;
    }

    // Set session language
    $_SESSION["language"] = $language;

    // Set the locale/environment language
    setlocale(LC_MESSAGES, $language, $language . 'utf-8', $language . 'utf8', "en_GB.utf8");
    putenv("LANG=" . $language);

    // Non-English numeric formats will turn decimals to commas and mess up all kinds of stuff
    // so we aren't going to do that
    setlocale(LC_NUMERIC, 'C');

    // Bind text domains
    bindtextdomain($language, $langdir);
    bind_textdomain_codeset($language, 'UTF-8');
    textdomain($language);
}


function init_language()
{
    // URL override
    $locale = grab_request_var('locale', '');
    if (!empty($locale)) {
        set_language($locale);
    }

    // Read session language if available
    if (!empty($_SESSION['language'])) {
        $session_language = $_SESSION['language'];
    } else {
        // Try user-specific and global default language from DB
        $udblang = get_user_meta('language');
        if (!empty($udblang)) {
            $session_language = $udblang;
        } else {
            $dblang = get_option('default_language', DEFAULT_LANGUAGE);
            $session_language = $dblang;
        }
    }

    set_language($session_language);
}


function get_languages()
{
    global $cfg;

    $dirs = scandir(dirname(__FILE__) . '/../lang/locale');

    // Add directories to language options
    foreach ($dirs as $dir) {
        if (is_dir(dirname(__FILE__) . '/lang/locale/' . $dir) && strpos($dir, '.') === false && !isset($cfg[$dir])) {
            $newlang = htmlentities(utf8_encode($dir), ENT_QUOTES, 'UTF-8');
            $cfg['languages'][$newlang] = $newlang;
            if ($newlang == 'en_EN') {
                $cfg['languages'][$newlang] = 'en_US';
            }
        }
    }

    return $cfg['languages'];
}


function get_language_nicename($lang) {
    
    $language_array = get_languages_as_array();

    if (array_key_exists($lang, $language_array))
        return $language_array[$lang];

    return $lang;
}

function get_languages_as_array() {
    
    return array(
        'en_US' => _('English'),
        'de_DE' => _('German'),
        'es_ES' => _('Spanish'),
        'fr_FR' => _('French'),
        'it_IT' => _('Italian'),
        'ja_JP' => _('Japanese'),
        'ko_KR' => _('Korean'),
        'pt_PT' => _('Portuguese'),
        'ru_RU' => _('Russian'),
        'zh_CN' => _('Simplified Chinese'),
        'zh_TW' => _('Traditional Chinese'),
        'pl_PL' => _('Polish')
        );
}
