#!/bin/bash -e

. ./fusion-sys.cfg

# Check whether we have sufficient privileges
if [ $(id -u) -ne 0 ]; then
    echo "This script needs to be run as root/superuser." >&2
    exit 1
fi

# Was previous step completed?
if [ ! -f installed.repos ]; then
    echo "Repos were not properly prepared - run previous script" >&2
    exit 1
fi

# Are prereqs already installed?
if [ -f installed.prereqs ]; then
    echo "Prereqs already installed - skipping..."
    echo "Note: If you want to update the RPMs installed on this system, run your package manager's update command"
    exit 0
fi

# =======================
# Install Prereqs
# -----------------------

# Run basic yum install for now
unsupported="false"
if [ "$distro" == "RedHatEnterpriseServer" ] || [ "$distro" == "CentOS" ]; then
	if [ "$dist" == "el6" ]; then
        yum install httpd mysql mysql-server php php-pdo php-mysql php-mbstring unzip ntp sysstat -y
        yum install -y "@Japanese Support" "@Chinese Support" "@Korean Support";
	elif [ "$dist" == "el7" ]; then
		yum install httpd mysql mariadb mariadb-server php php-pdo php-mysql php-mbstring unzip ntp sysstat -y
	else
        unsupported="true"
	fi
else
    unsupported="true"
fi

if [ "x$unsupported" = "xtrue" ]; then
    echo "Operating system not supported. Supported OS are CentOS/RHEL 6 or 7."
fi

echo "Prerequisites installed OK"
touch installed.prereqs