#!/bin/bash -e

. ./fusion-sys.cfg

# Was previous step completed?
if [ ! -f installed.general ]; then
    echo "General setup was not completed" >&2
    exit 1
fi

# Is basedir already installed?
if [ -f installed.basedir ]; then
    echo "Base directory structure already installed - skipping..."
    exit 0
fi

echo "Installing Nagios Fusion base files..."

echo "Creating product directory..."
if [ ! -d "$proddir" ]; then
    eval "$mkdirbin" -p "$proddir"
fi

# Copy over Fusion files
cp -r ../fusion/* "$proddir"

# Change ownership on directories and files
chown -R "$nagiosuser:$nagiosgroup" "$proddir"

# Set permissions on temp directory
chown -R "$apacheuser:$nagiosgroup" "$proddir/tmp"
chmod -R 6775 "$proddir/tmp"

# Add main Apache conf file
cp inc/httpd.conf "$httpdconfdir/nagiosfusion.conf"

# Modify the configuration file for Apache 2.4
if [[ $ver -eq 7 && "$distro" != "Debian" ]] || [ "$distro" == "Ubuntu" ] || [[ "$distro" == "Debian" && $ver -eq 8 ]]; then
	sed -i '/<\/Directory>/c\	Require all granted\n</Directory>' "$httpdconfdir/nagiosfusion.conf"
fi

# Restart Apache to apply perms
if [ ! `command -v systemctl` ]; then
    service $httpd restart
else
    systemctl restart $httpd
fi

# Install system config file
cp fusion-sys.cfg "$proddir/var/"
cp fusion-sys.cfg ../fusion/var/

# Set fusion uuid and source install type
if [ ! -f $proddir/var/fusion-uuid ]; then
    uuidgen >> $proddir/var/fusion-uuid
fi
echo "source" >> $proddir/var/fusion-itype
chown $nagiosuser:$nagiosgroup $proddir/var/fusion-*

echo "Base directory structure installed OK"
touch installed.basedir